# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentTypes, EntityState, FileTypes


class UpdateContent(BaseModel):
    update_content: Optional["UpdateContentUpdateContent"] = Field(
        alias="updateContent"
    )


class UpdateContentUpdateContent(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    uri: Optional[Any]
    collections: Optional[List[Optional["UpdateContentUpdateContentCollections"]]]


class UpdateContentUpdateContentCollections(BaseModel):
    id: str
    name: str


UpdateContent.model_rebuild()
UpdateContentUpdateContent.model_rebuild()



# Generated by ariadne-codegen
# Source: https://data-scus.graphlit.io/api/v1/graphql

from enum import Enum


class ApplyPolicy(str, Enum):
    BEFORE_RESOLVER = "BEFORE_RESOLVER"
    AFTER_RESOLVER = "AFTER_RESOLVER"
    VALIDATION = "VALIDATION"


class H3ResolutionTypes(str, Enum):
    R0 = "R0"
    R1 = "R1"
    R2 = "R2"
    R3 = "R3"
    R4 = "R4"
    R5 = "R5"
    R6 = "R6"
    R7 = "R7"
    R8 = "R8"
    R9 = "R9"
    R10 = "R10"
    R11 = "R11"
    R12 = "R12"
    R13 = "R13"
    R14 = "R14"
    R15 = "R15"


class TimeIntervalTypes(str, Enum):
    MINUTE = "MINUTE"
    HOUR = "HOUR"
    DAY = "DAY"
    WEEK = "WEEK"
    MONTH = "MONTH"
    QUARTER = "QUARTER"
    YEAR = "YEAR"


class EntityState(str, Enum):
    INITIALIZED = "INITIALIZED"
    RESTARTED = "RESTARTED"
    CREATED = "CREATED"
    INGESTED = "INGESTED"
    INDEXED = "INDEXED"
    PREPARED = "PREPARED"
    SANITIZED = "SANITIZED"
    EXTRACTED = "EXTRACTED"
    ENRICHED = "ENRICHED"
    CHANGED = "CHANGED"
    ARCHIVED = "ARCHIVED"
    APPROVED = "APPROVED"
    REJECTED = "REJECTED"
    PENDING = "PENDING"
    QUEUED = "QUEUED"
    OPENED = "OPENED"
    CLOSED = "CLOSED"
    FINISHED = "FINISHED"
    PAUSED = "PAUSED"
    RUNNING = "RUNNING"
    SUBSCRIBED = "SUBSCRIBED"
    ERRORED = "ERRORED"
    ENABLED = "ENABLED"
    DISABLED = "DISABLED"
    DELETED = "DELETED"


class AlertTypes(str, Enum):
    PROMPT = "PROMPT"


class CollectionTypes(str, Enum):
    COLLECTION = "COLLECTION"


class FacetValueTypes(str, Enum):
    VALUE = "VALUE"
    RANGE = "RANGE"
    OBJECT = "OBJECT"


class ContentFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"
    ORIGINAL_DATE = "ORIGINAL_DATE"
    OBSERVABLE = "OBSERVABLE"
    CONTENT_TYPE = "CONTENT_TYPE"
    FILE_TYPE = "FILE_TYPE"
    FORMAT = "FORMAT"
    FORMAT_NAME = "FORMAT_NAME"
    FILE_EXTENSION = "FILE_EXTENSION"
    FILE_SIZE = "FILE_SIZE"
    DEVICE_TYPE = "DEVICE_TYPE"
    IMAGE_MAKE = "IMAGE_MAKE"
    IMAGE_MODEL = "IMAGE_MODEL"
    IMAGE_SOFTWARE = "IMAGE_SOFTWARE"
    AUDIO_AUTHOR = "AUDIO_AUTHOR"
    AUDIO_SERIES = "AUDIO_SERIES"
    AUDIO_PUBLISHER = "AUDIO_PUBLISHER"
    VIDEO_MAKE = "VIDEO_MAKE"
    VIDEO_MODEL = "VIDEO_MODEL"
    VIDEO_SOFTWARE = "VIDEO_SOFTWARE"
    DOCUMENT_AUTHOR = "DOCUMENT_AUTHOR"
    DOCUMENT_PUBLISHER = "DOCUMENT_PUBLISHER"
    DOCUMENT_IS_ENCRYPTED = "DOCUMENT_IS_ENCRYPTED"
    DOCUMENT_HAS_DIGITAL_SIGNATURE = "DOCUMENT_HAS_DIGITAL_SIGNATURE"
    EMAIL_PRIORITY = "EMAIL_PRIORITY"
    EMAIL_SENSITIVITY = "EMAIL_SENSITIVITY"
    ISSUE_PROJECT = "ISSUE_PROJECT"
    ISSUE_TEAM = "ISSUE_TEAM"
    ISSUE_PRIORITY = "ISSUE_PRIORITY"
    ISSUE_STATUS = "ISSUE_STATUS"
    ISSUE_TYPE = "ISSUE_TYPE"


class ContentTypes(str, Enum):
    FILE = "FILE"
    PAGE = "PAGE"
    MESSAGE = "MESSAGE"
    TEXT = "TEXT"
    POST = "POST"
    EMAIL = "EMAIL"
    EVENT = "EVENT"
    ISSUE = "ISSUE"


class FileTypes(str, Enum):
    VIDEO = "VIDEO"
    AUDIO = "AUDIO"
    IMAGE = "IMAGE"
    ANIMATION = "ANIMATION"
    DOCUMENT = "DOCUMENT"
    EMAIL = "EMAIL"
    CODE = "CODE"
    DATA = "DATA"
    PACKAGE = "PACKAGE"
    SHAPE = "SHAPE"
    POINT_CLOUD = "POINT_CLOUD"
    GEOMETRY = "GEOMETRY"
    DRAWING = "DRAWING"
    MANIFEST = "MANIFEST"
    UNKNOWN = "UNKNOWN"


class DeviceTypes(str, Enum):
    DRONE = "DRONE"
    ROBOT = "ROBOT"
    MOBILE = "MOBILE"
    CAMERA = "CAMERA"
    STREAM = "STREAM"
    SCREEN = "SCREEN"
    GEOSPATIAL = "GEOSPATIAL"
    UNKNOWN = "UNKNOWN"


class ConversationTypes(str, Enum):
    CONTENT = "CONTENT"


class FeedTypes(str, Enum):
    NOTION = "NOTION"
    SLACK = "SLACK"
    MICROSOFT_TEAMS = "MICROSOFT_TEAMS"
    DISCORD = "DISCORD"
    REDDIT = "REDDIT"
    WEB = "WEB"
    RSS = "RSS"
    SITE = "SITE"
    YOU_TUBE = "YOU_TUBE"
    EMAIL = "EMAIL"
    ISSUE = "ISSUE"
    SEARCH = "SEARCH"


class MetadataTypes(str, Enum):
    CONTENT = "CONTENT"


class ObservableTypes(str, Enum):
    CATEGORY = "CATEGORY"
    LABEL = "LABEL"
    EVENT = "EVENT"
    ORGANIZATION = "ORGANIZATION"
    PERSON = "PERSON"
    PLACE = "PLACE"
    PRODUCT = "PRODUCT"
    REPO = "REPO"
    SOFTWARE = "SOFTWARE"
    MEDICAL_STUDY = "MEDICAL_STUDY"
    MEDICAL_CONDITION = "MEDICAL_CONDITION"
    MEDICAL_GUIDELINE = "MEDICAL_GUIDELINE"
    MEDICAL_DRUG = "MEDICAL_DRUG"
    MEDICAL_DRUG_CLASS = "MEDICAL_DRUG_CLASS"
    MEDICAL_INDICATION = "MEDICAL_INDICATION"
    MEDICAL_CONTRAINDICATION = "MEDICAL_CONTRAINDICATION"
    MEDICAL_TEST = "MEDICAL_TEST"
    MEDICAL_DEVICE = "MEDICAL_DEVICE"
    MEDICAL_THERAPY = "MEDICAL_THERAPY"
    MEDICAL_PROCEDURE = "MEDICAL_PROCEDURE"


class OrganizationFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class PersonFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class PlaceFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class EnvironmentTypes(str, Enum):
    DEVELOPMENT = "DEVELOPMENT"
    PRODUCTION = "PRODUCTION"


class ResourceConnectorTypes(str, Enum):
    AMAZON = "AMAZON"
    AZURE = "AZURE"
    GOOGLE = "GOOGLE"


class RenditionTypes(str, Enum):
    CONTENT = "CONTENT"


class SpecificationTypes(str, Enum):
    COMPLETION = "COMPLETION"
    TEXT_EMBEDDING = "TEXT_EMBEDDING"
    IMAGE_EMBEDDING = "IMAGE_EMBEDDING"
    EXTRACTION = "EXTRACTION"
    PREPARATION = "PREPARATION"


class ModelServiceTypes(str, Enum):
    GOOGLE = "GOOGLE"
    ANTHROPIC = "ANTHROPIC"
    AZURE_AI = "AZURE_AI"
    AZURE_OPEN_AI = "AZURE_OPEN_AI"
    OPEN_AI = "OPEN_AI"
    REPLICATE = "REPLICATE"
    GROQ = "GROQ"
    CEREBRAS = "CEREBRAS"
    MISTRAL = "MISTRAL"
    COHERE = "COHERE"
    DEEPSEEK = "DEEPSEEK"
    JINA = "JINA"
    VOYAGE = "VOYAGE"


class ConversationSearchTypes(str, Enum):
    VECTOR = "VECTOR"
    HYBRID = "HYBRID"


class OrderByTypes(str, Enum):
    NAME = "NAME"
    CREATION_DATE = "CREATION_DATE"
    ORIGINAL_DATE = "ORIGINAL_DATE"
    RELEVANCE = "RELEVANCE"


class OrderDirectionTypes(str, Enum):
    ASCENDING = "ASCENDING"
    DESCENDING = "DESCENDING"


class SearchTypes(str, Enum):
    KEYWORD = "KEYWORD"
    VECTOR = "VECTOR"
    HYBRID = "HYBRID"


class SearchQueryTypes(str, Enum):
    SIMPLE = "SIMPLE"
    FULL = "FULL"


class ContentPublishingServiceTypes(str, Enum):
    ELEVEN_LABS_AUDIO = "ELEVEN_LABS_AUDIO"
    TEXT = "TEXT"


class ContentPublishingFormats(str, Enum):
    MP3 = "MP3"
    TEXT = "TEXT"
    MARKDOWN = "MARKDOWN"
    HTML = "HTML"


class IntegrationServiceTypes(str, Enum):
    SLACK = "SLACK"
    WEB_HOOK = "WEB_HOOK"


class TimedPolicyRecurrenceTypes(str, Enum):
    ONCE = "ONCE"
    REPEAT = "REPEAT"


class PolicyTimeTypes(str, Enum):
    RELATIVE_TIME = "RELATIVE_TIME"
    ABSOLUTE_TIME = "ABSOLUTE_TIME"


class LinkTypes(str, Enum):
    TYPE_FORM = "TYPE_FORM"
    AIRTABLE = "AIRTABLE"
    MICROSOFT_TEAMS = "MICROSOFT_TEAMS"
    DISCORD = "DISCORD"
    APPLE = "APPLE"
    SLACK = "SLACK"
    ANGEL_LIST = "ANGEL_LIST"
    CRUNCHBASE = "CRUNCHBASE"
    LINKED_IN = "LINKED_IN"
    DIFFBOT = "DIFFBOT"
    REDDIT = "REDDIT"
    GOOGLE = "GOOGLE"
    IFTTT = "IFTTT"
    FACEBOOK = "FACEBOOK"
    WIKIPEDIA = "WIKIPEDIA"
    WIKIMEDIA = "WIKIMEDIA"
    WIKIDATA = "WIKIDATA"
    INSTAGRAM = "INSTAGRAM"
    TWITCH = "TWITCH"
    POCKET_CASTS = "POCKET_CASTS"
    SPOTIFY = "SPOTIFY"
    TUNE_IN = "TUNE_IN"
    STITCHER = "STITCHER"
    ANCHOR_FM = "ANCHOR_FM"
    TRANSISTOR_FM = "TRANSISTOR_FM"
    I_TUNES = "I_TUNES"
    PANDORA = "PANDORA"
    SOUND_CLOUD = "SOUND_CLOUD"
    BANDCAMP = "BANDCAMP"
    TIK_TOK = "TIK_TOK"
    YOU_TUBE = "YOU_TUBE"
    TWITTER = "TWITTER"
    X = "X"
    MEDIUM = "MEDIUM"
    NOTION = "NOTION"
    LINEAR = "LINEAR"
    GIT_HUB = "GIT_HUB"
    GIT_HUB_PAGES = "GIT_HUB_PAGES"
    RSS = "RSS"
    EMAIL = "EMAIL"
    MEDIA = "MEDIA"
    WEB = "WEB"
    FILE = "FILE"


class ImageProjectionTypes(str, Enum):
    EQUIRECTANGULAR = "EQUIRECTANGULAR"
    CYLINDRICAL = "CYLINDRICAL"


class OrientationTypes(str, Enum):
    TOP_LEFT = "TOP_LEFT"
    TOP_RIGHT = "TOP_RIGHT"
    BOTTOM_RIGHT = "BOTTOM_RIGHT"
    BOTTOM_LEFT = "BOTTOM_LEFT"
    LEFT_TOP = "LEFT_TOP"
    RIGHT_TOP = "RIGHT_TOP"
    RIGHT_BOTTOM = "RIGHT_BOTTOM"
    LEFT_BOTTOM = "LEFT_BOTTOM"


class MailSensitivity(str, Enum):
    NONE = "NONE"
    NORMAL = "NORMAL"
    PERSONAL = "PERSONAL"
    PRIVATE = "PRIVATE"
    COMPANY_CONFIDENTIAL = "COMPANY_CONFIDENTIAL"


class MailPriority(str, Enum):
    NORMAL = "NORMAL"
    LOW = "LOW"
    HIGH = "HIGH"


class MailImportance(str, Enum):
    NORMAL = "NORMAL"
    LOW = "LOW"
    HIGH = "HIGH"


class UnitTypes(str, Enum):
    KILOMETER = "KILOMETER"
    METER = "METER"
    CENTIMETER = "CENTIMETER"
    MILLIMETER = "MILLIMETER"
    MICROMETER = "MICROMETER"
    NANOMETER = "NANOMETER"
    ANGSTROM = "ANGSTROM"
    DECIMETER = "DECIMETER"
    DECAMETER = "DECAMETER"
    HECTOMETER = "HECTOMETER"
    GIGAMETER = "GIGAMETER"
    ASTRONOMICAL_UNIT = "ASTRONOMICAL_UNIT"
    LIGHT_YEAR = "LIGHT_YEAR"
    PARSEC = "PARSEC"
    MILE = "MILE"
    YARD = "YARD"
    FOOT = "FOOT"
    INCH = "INCH"
    MIL = "MIL"
    MICRO_INCH = "MICRO_INCH"
    CUSTOM = "CUSTOM"
    UNITLESS = "UNITLESS"


class ConversationRoleTypes(str, Enum):
    SYSTEM = "SYSTEM"
    ASSISTANT = "ASSISTANT"
    USER = "USER"


class SiteTypes(str, Enum):
    WATCH = "WATCH"
    SWEEP = "SWEEP"
    STORAGE = "STORAGE"


class FeedConnectorTypes(str, Enum):
    GOOGLE = "GOOGLE"
    AMAZON = "AMAZON"
    AZURE = "AZURE"
    SHARE_POINT = "SHARE_POINT"
    ONE_DRIVE = "ONE_DRIVE"
    GOOGLE_DRIVE = "GOOGLE_DRIVE"
    GOOGLE_EMAIL = "GOOGLE_EMAIL"
    MICROSOFT_EMAIL = "MICROSOFT_EMAIL"
    ATLASSIAN = "ATLASSIAN"
    LINEAR = "LINEAR"
    GIT_HUB = "GIT_HUB"


class FeedServiceTypes(str, Enum):
    GOOGLE_BLOB = "GOOGLE_BLOB"
    S3_BLOB = "S3_BLOB"
    AZURE_BLOB = "AZURE_BLOB"
    AZURE_FILE = "AZURE_FILE"
    SHARE_POINT = "SHARE_POINT"
    ONE_DRIVE = "ONE_DRIVE"
    GOOGLE_DRIVE = "GOOGLE_DRIVE"
    GOOGLE_EMAIL = "GOOGLE_EMAIL"
    MICROSOFT_EMAIL = "MICROSOFT_EMAIL"
    ATLASSIAN_JIRA = "ATLASSIAN_JIRA"
    LINEAR = "LINEAR"
    GIT_HUB_ISSUES = "GIT_HUB_ISSUES"
    GIT_HUB = "GIT_HUB"


class SearchServiceTypes(str, Enum):
    TAVILY = "TAVILY"
    EXA = "EXA"


class YouTubeTypes(str, Enum):
    VIDEO = "VIDEO"
    VIDEOS = "VIDEOS"
    PLAYLIST = "PLAYLIST"
    CHANNEL = "CHANNEL"


class NotionTypes(str, Enum):
    PAGE = "PAGE"
    DATABASE = "DATABASE"


class FeedListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class OccurrenceTypes(str, Enum):
    IMAGE = "IMAGE"
    TIME = "TIME"
    TEXT = "TEXT"


class ConversationStrategyTypes(str, Enum):
    WINDOWED = "WINDOWED"
    SUMMARIZED = "SUMMARIZED"


class PromptStrategyTypes(str, Enum):
    OPTIMIZE_SEARCH = "OPTIMIZE_SEARCH"
    REWRITE = "REWRITE"
    NONE = "NONE"


class RetrievalStrategyTypes(str, Enum):
    CONTENT = "CONTENT"
    CHUNK = "CHUNK"
    SECTION = "SECTION"


class RerankingModelServiceTypes(str, Enum):
    COHERE = "COHERE"
    JINA = "JINA"
    VOYAGE = "VOYAGE"


class GraphStrategyTypes(str, Enum):
    EXTRACT_ENTITIES_FILTER = "EXTRACT_ENTITIES_FILTER"
    EXTRACT_ENTITIES_GRAPH = "EXTRACT_ENTITIES_GRAPH"
    NONE = "NONE"


class RevisionStrategyTypes(str, Enum):
    REVISE = "REVISE"
    CUSTOM = "CUSTOM"
    NONE = "NONE"


class OpenAIModels(str, Enum):
    GPT35_TURBO = "GPT35_TURBO"
    GPT35_TURBO_0613 = "GPT35_TURBO_0613"
    GPT35_TURBO_16K = "GPT35_TURBO_16K"
    GPT35_TURBO_16K_0613 = "GPT35_TURBO_16K_0613"
    GPT35_TURBO_16K_1106 = "GPT35_TURBO_16K_1106"
    GPT35_TURBO_16K_0125 = "GPT35_TURBO_16K_0125"
    GPT4 = "GPT4"
    GPT4_0613 = "GPT4_0613"
    GPT4_TURBO_VISION_128K = "GPT4_TURBO_VISION_128K"
    GPT4_TURBO_VISION_128K_1106 = "GPT4_TURBO_VISION_128K_1106"
    GPT4_32K = "GPT4_32K"
    GPT4_32K_0613 = "GPT4_32K_0613"
    GPT4_TURBO_128K = "GPT4_TURBO_128K"
    GPT4_TURBO_128K_1106 = "GPT4_TURBO_128K_1106"
    GPT4_TURBO_128K_0125 = "GPT4_TURBO_128K_0125"
    GPT4_TURBO_128K_20240409 = "GPT4_TURBO_128K_20240409"
    GPT4O_128K_20240513 = "GPT4O_128K_20240513"
    GPT4O_128K_20240806 = "GPT4O_128K_20240806"
    GPT4O_128K = "GPT4O_128K"
    GPT4O_MINI_128K_20240718 = "GPT4O_MINI_128K_20240718"
    GPT4O_MINI_128K = "GPT4O_MINI_128K"
    GPT4O_CHAT_128K = "GPT4O_CHAT_128K"
    O1_MINI_128K = "O1_MINI_128K"
    O1_MINI_128K_20240912 = "O1_MINI_128K_20240912"
    O1_PREVIEW_128K = "O1_PREVIEW_128K"
    O1_PREVIEW_128K_20240912 = "O1_PREVIEW_128K_20240912"
    ADA_002 = "ADA_002"
    EMBEDDING_3_SMALL = "EMBEDDING_3_SMALL"
    EMBEDDING_3_LARGE = "EMBEDDING_3_LARGE"
    CUSTOM = "CUSTOM"


class OpenAIVisionDetailLevels(str, Enum):
    HIGH = "HIGH"
    LOW = "LOW"


class AzureOpenAIModels(str, Enum):
    GPT35_TURBO_16K = "GPT35_TURBO_16K"
    GPT4 = "GPT4"
    GPT4_TURBO_128K = "GPT4_TURBO_128K"
    CUSTOM = "CUSTOM"


class CohereModels(str, Enum):
    EMBED_ENGLISH_3_0 = "EMBED_ENGLISH_3_0"
    EMBED_MULTILINGUAL_3_0 = "EMBED_MULTILINGUAL_3_0"
    COMMAND_R = "COMMAND_R"
    COMMAND_R_202403 = "COMMAND_R_202403"
    COMMAND_R_202408 = "COMMAND_R_202408"
    COMMAND_R_PLUS = "COMMAND_R_PLUS"
    COMMAND_R_PLUS_202404 = "COMMAND_R_PLUS_202404"
    COMMAND_R_PLUS_202408 = "COMMAND_R_PLUS_202408"
    CUSTOM = "CUSTOM"


class AnthropicModels(str, Enum):
    CLAUDE_2 = "CLAUDE_2"
    CLAUDE_2_0 = "CLAUDE_2_0"
    CLAUDE_2_1 = "CLAUDE_2_1"
    CLAUDE_INSTANT_1 = "CLAUDE_INSTANT_1"
    CLAUDE_INSTANT_1_2 = "CLAUDE_INSTANT_1_2"
    CLAUDE_3_OPUS = "CLAUDE_3_OPUS"
    CLAUDE_3_SONNET = "CLAUDE_3_SONNET"
    CLAUDE_3_HAIKU = "CLAUDE_3_HAIKU"
    CLAUDE_3_5_SONNET = "CLAUDE_3_5_SONNET"
    CUSTOM = "CUSTOM"


class GoogleModels(str, Enum):
    GEMINI_1_5_FLASH_8B = "GEMINI_1_5_FLASH_8B"
    GEMINI_1_5_FLASH_8B_001 = "GEMINI_1_5_FLASH_8B_001"
    GEMINI_1_5_FLASH = "GEMINI_1_5_FLASH"
    GEMINI_1_5_PRO = "GEMINI_1_5_PRO"
    GEMINI_1_5_FLASH_001 = "GEMINI_1_5_FLASH_001"
    GEMINI_1_5_PRO_001 = "GEMINI_1_5_PRO_001"
    GEMINI_1_5_FLASH_002 = "GEMINI_1_5_FLASH_002"
    GEMINI_1_5_PRO_002 = "GEMINI_1_5_PRO_002"
    EMBEDDING_004 = "EMBEDDING_004"
    CUSTOM = "CUSTOM"


class ReplicateModels(str, Enum):
    MISTRAL_7B = "MISTRAL_7B"
    MISTRAL_7B_INSTRUCT = "MISTRAL_7B_INSTRUCT"
    LLAMA_2_7B = "LLAMA_2_7B"
    LLAMA_2_13B = "LLAMA_2_13B"
    LLAMA_2_70B = "LLAMA_2_70B"
    LLAMA_2_7B_CHAT = "LLAMA_2_7B_CHAT"
    LLAMA_2_13B_CHAT = "LLAMA_2_13B_CHAT"
    LLAMA_2_70B_CHAT = "LLAMA_2_70B_CHAT"
    CUSTOM = "CUSTOM"


class MistralModels(str, Enum):
    MIXTRAL_8X7B_INSTRUCT = "MIXTRAL_8X7B_INSTRUCT"
    MISTRAL_NEMO = "MISTRAL_NEMO"
    MISTRAL_SMALL = "MISTRAL_SMALL"
    MISTRAL_MEDIUM = "MISTRAL_MEDIUM"
    MISTRAL_LARGE = "MISTRAL_LARGE"
    PIXTRAL_12B_2409 = "PIXTRAL_12B_2409"
    MISTRAL_EMBED = "MISTRAL_EMBED"
    CUSTOM = "CUSTOM"


class GroqModels(str, Enum):
    LLAVA_1_5_7B_PREVIEW = "LLAVA_1_5_7B_PREVIEW"
    MIXTRAL_8X7B_INSTRUCT = "MIXTRAL_8X7B_INSTRUCT"
    LLAMA_3_2_90B_TEXT_PREVIEW = "LLAMA_3_2_90B_TEXT_PREVIEW"
    LLAMA_3_2_11B_TEXT_PREVIEW = "LLAMA_3_2_11B_TEXT_PREVIEW"
    LLAMA_3_2_11B_VISION_PREVIEW = "LLAMA_3_2_11B_VISION_PREVIEW"
    LLAMA_3_2_3B_PREVIEW = "LLAMA_3_2_3B_PREVIEW"
    LLAMA_3_2_1B_PREVIEW = "LLAMA_3_2_1B_PREVIEW"
    LLAMA_3_1_405B = "LLAMA_3_1_405B"
    LLAMA_3_1_70B = "LLAMA_3_1_70B"
    LLAMA_3_1_8B = "LLAMA_3_1_8B"
    LLAMA_3_70B = "LLAMA_3_70B"
    LLAMA_3_8B = "LLAMA_3_8B"
    CUSTOM = "CUSTOM"


class CerebrasModels(str, Enum):
    LLAMA_3_1_70B = "LLAMA_3_1_70B"
    LLAMA_3_1_8B = "LLAMA_3_1_8B"
    CUSTOM = "CUSTOM"


class DeepseekModels(str, Enum):
    CHAT = "CHAT"
    CODER = "CODER"
    CUSTOM = "CUSTOM"


class JinaModels(str, Enum):
    CLIP_IMAGE = "CLIP_IMAGE"
    EMBED = "EMBED"
    EMBED_3_0 = "EMBED_3_0"
    CUSTOM = "CUSTOM"


class VoyageModels(str, Enum):
    VOYAGE = "VOYAGE"
    VOYAGE_3_0 = "VOYAGE_3_0"
    VOYAGE_LITE_3_0 = "VOYAGE_LITE_3_0"
    VOYAGE_FINANCE_2_0 = "VOYAGE_FINANCE_2_0"
    VOYAGE_MULTILINGUAL_2_0 = "VOYAGE_MULTILINGUAL_2_0"
    VOYAGE_LAW_2_0 = "VOYAGE_LAW_2_0"
    VOYAGE_CODE_2_0 = "VOYAGE_CODE_2_0"
    CUSTOM = "CUSTOM"


class ElevenLabsModels(str, Enum):
    MULTILINGUAL_V1 = "MULTILINGUAL_V1"
    MULTILINGUAL_V2 = "MULTILINGUAL_V2"
    ENGLISH_V1 = "ENGLISH_V1"
    TURBO_V2 = "TURBO_V2"
    TURBO_V2_5 = "TURBO_V2_5"


class TextRoles(str, Enum):
    PAGE_HEADER = "PAGE_HEADER"
    PAGE_FOOTER = "PAGE_FOOTER"
    PAGE_NUMBER = "PAGE_NUMBER"
    TITLE = "TITLE"
    SECTION_HEADING = "SECTION_HEADING"
    FOOTNOTE = "FOOTNOTE"
    CODE = "CODE"
    LIST_ITEM = "LIST_ITEM"
    HEADING1 = "HEADING1"
    HEADING2 = "HEADING2"
    HEADING3 = "HEADING3"
    HEADING4 = "HEADING4"
    HEADING5 = "HEADING5"
    TABLE_COLUMN_HEADER = "TABLE_COLUMN_HEADER"
    TABLE_ROW_HEADER = "TABLE_ROW_HEADER"
    TABLE_CORNER_HEADER = "TABLE_CORNER_HEADER"
    TABLE_CELL = "TABLE_CELL"
    TABLE_CAPTION = "TABLE_CAPTION"
    TABLE = "TABLE"
    FIGURE = "FIGURE"
    DIAGRAM = "DIAGRAM"
    WATERMARK = "WATERMARK"
    EQUATION = "EQUATION"
    PARAGRAPH = "PARAGRAPH"
    CHECKBOX = "CHECKBOX"
    RADIO_BUTTON = "RADIO_BUTTON"
    COLUMN_HEADER = "COLUMN_HEADER"
    ROW_HEADER = "ROW_HEADER"
    CORNER_HEADER = "CORNER_HEADER"


class SharePointAuthenticationTypes(str, Enum):
    APPLICATION = "APPLICATION"
    USER = "USER"


class EmailListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class SummarizationTypes(str, Enum):
    SUMMARY = "SUMMARY"
    KEYWORDS = "KEYWORDS"
    BULLETS = "BULLETS"
    HEADLINES = "HEADLINES"
    POSTS = "POSTS"
    CHAPTERS = "CHAPTERS"
    QUESTIONS = "QUESTIONS"
    CUSTOM = "CUSTOM"


class ContentIndexingServiceTypes(str, Enum):
    AZURE_AI_LANGUAGE = "AZURE_AI_LANGUAGE"


class FilePreparationServiceTypes(str, Enum):
    AZURE_DOCUMENT_INTELLIGENCE = "AZURE_DOCUMENT_INTELLIGENCE"
    DEEPGRAM = "DEEPGRAM"
    DOCUMENT = "DOCUMENT"
    EMAIL = "EMAIL"
    MODEL_DOCUMENT = "MODEL_DOCUMENT"


class EntityExtractionServiceTypes(str, Enum):
    ROBOFLOW_IMAGE = "ROBOFLOW_IMAGE"
    MODEL_TEXT = "MODEL_TEXT"
    MODEL_IMAGE = "MODEL_IMAGE"
    OPEN_AI_IMAGE = "OPEN_AI_IMAGE"
    AZURE_COGNITIVE_SERVICES_IMAGE = "AZURE_COGNITIVE_SERVICES_IMAGE"
    AZURE_COGNITIVE_SERVICES_TEXT = "AZURE_COGNITIVE_SERVICES_TEXT"


class EntityEnrichmentServiceTypes(str, Enum):
    DIFFBOT = "DIFFBOT"
    WIKIPEDIA = "WIKIPEDIA"
    CRUNCHBASE = "CRUNCHBASE"
    FHIR = "FHIR"


class AzureDocumentIntelligenceModels(str, Enum):
    READ_OCR = "READ_OCR"
    LAYOUT = "LAYOUT"
    INVOICE = "INVOICE"
    RECEIPT = "RECEIPT"
    IDENTIFICATION_DOCUMENT = "IDENTIFICATION_DOCUMENT"
    US_HEALTH_INSURANCE_CARD = "US_HEALTH_INSURANCE_CARD"
    US_TAX_FORM_W2 = "US_TAX_FORM_W2"
    US_TAX_FORM1098 = "US_TAX_FORM1098"
    US_TAX_FORM1098_E = "US_TAX_FORM1098_E"
    US_TAX_FORM1098_T = "US_TAX_FORM1098_T"
    US_TAX_FORM1099 = "US_TAX_FORM1099"
    US_MARRIAGE_CERTIFICATE = "US_MARRIAGE_CERTIFICATE"
    US_MORTGAGE1003 = "US_MORTGAGE1003"
    US_MORTGAGE1008 = "US_MORTGAGE1008"
    US_MORTGAGE_DISCLOSURE = "US_MORTGAGE_DISCLOSURE"
    CREDIT_CARD = "CREDIT_CARD"


class AzureDocumentIntelligenceVersions(str, Enum):
    V2023_07_31 = "V2023_07_31"
    V2024_02_29_PREVIEW = "V2024_02_29_PREVIEW"
    V2024_07_31_PREVIEW = "V2024_07_31_PREVIEW"


class DeepgramModels(str, Enum):
    NOVA2 = "NOVA2"
    NOVA2_MEETING = "NOVA2_MEETING"
    NOVA2_PHONECALL = "NOVA2_PHONECALL"
    NOVA2_VOICEMAIL = "NOVA2_VOICEMAIL"
    NOVA2_FINANCE = "NOVA2_FINANCE"
    NOVA2_CONVERSATIONAL_AI = "NOVA2_CONVERSATIONAL_AI"
    NOVA2_VIDEO = "NOVA2_VIDEO"
    NOVA2_MEDICAL = "NOVA2_MEDICAL"
    NOVA2_DRIVETHRU = "NOVA2_DRIVETHRU"
    NOVA2_AUTOMOTIVE = "NOVA2_AUTOMOTIVE"
    WHISPER_TINY = "WHISPER_TINY"
    WHISPER_SMALL = "WHISPER_SMALL"
    WHISPER_BASE = "WHISPER_BASE"
    WHISPER_MEDIUM = "WHISPER_MEDIUM"
    WHISPER_LARGE = "WHISPER_LARGE"


class TextTypes(str, Enum):
    PLAIN = "PLAIN"
    MARKDOWN = "MARKDOWN"
    HTML = "HTML"


class CategoryFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class EventFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class LabelFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalStudyFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalConditionFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalGuidelineFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalDrugFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalDrugClassFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalContraindicationFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalIndicationFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalProcedureFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalDeviceFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalTherapyFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MedicalTestFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class ProductFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class BillableMetrics(str, Enum):
    BYTES = "BYTES"
    TOKENS = "TOKENS"
    LENGTH = "LENGTH"
    TIME = "TIME"
    UNITS = "UNITS"
    COST = "COST"
    REQUESTS = "REQUESTS"
    CREDITS = "CREDITS"


class EntityTypes(str, Enum):
    ACTIVITY = "ACTIVITY"
    ALERT = "ALERT"
    CATEGORY = "CATEGORY"
    COLLECTION = "COLLECTION"
    CONNECTOR = "CONNECTOR"
    CONTENT = "CONTENT"
    CONVERSATION = "CONVERSATION"
    EVENT = "EVENT"
    FEED = "FEED"
    JOB = "JOB"
    LABEL = "LABEL"
    METADATA = "METADATA"
    MEDICAL_STUDY = "MEDICAL_STUDY"
    MEDICAL_CONDITION = "MEDICAL_CONDITION"
    MEDICAL_GUIDELINE = "MEDICAL_GUIDELINE"
    MEDICAL_DRUG = "MEDICAL_DRUG"
    MEDICAL_DRUG_CLASS = "MEDICAL_DRUG_CLASS"
    MEDICAL_INDICATION = "MEDICAL_INDICATION"
    MEDICAL_CONTRAINDICATION = "MEDICAL_CONTRAINDICATION"
    MEDICAL_TEST = "MEDICAL_TEST"
    MEDICAL_DEVICE = "MEDICAL_DEVICE"
    MEDICAL_THERAPY = "MEDICAL_THERAPY"
    MEDICAL_PROCEDURE = "MEDICAL_PROCEDURE"
    OBSERVATION = "OBSERVATION"
    ORGANIZATION = "ORGANIZATION"
    PERSON = "PERSON"
    PLACE = "PLACE"
    PRODUCT = "PRODUCT"
    PROJECT = "PROJECT"
    RENDITION = "RENDITION"
    REPO = "REPO"
    SITE = "SITE"
    SOFTWARE = "SOFTWARE"
    SPECIFICATION = "SPECIFICATION"
    WORKFLOW = "WORKFLOW"


class OperationTypes(str, Enum):
    QUERY = "QUERY"
    MUTATION = "MUTATION"


class RepoFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class SoftwareFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    EntityState,
    FileTypes,
    ImageProjectionTypes,
    LinkTypes,
    MailImportance,
    MailPriority,
    MailSensitivity,
    ObservableTypes,
    OccurrenceTypes,
    OrientationTypes,
    TextRoles,
)


class QueryContents(BaseModel):
    contents: Optional["QueryContentsContents"]


class QueryContentsContents(BaseModel):
    results: Optional[List[Optional["QueryContentsContentsResults"]]]


class QueryContentsContentsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "QueryContentsContentsResultsOwner"
    state: EntityState
    original_date: Optional[Any] = Field(alias="originalDate")
    finished_date: Optional[Any] = Field(alias="finishedDate")
    workflow_duration: Optional[Any] = Field(alias="workflowDuration")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    markdown: Optional[str]
    address: Optional["QueryContentsContentsResultsAddress"]
    location: Optional["QueryContentsContentsResultsLocation"]
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    file_name: Optional[str] = Field(alias="fileName")
    file_size: Optional[Any] = Field(alias="fileSize")
    master_uri: Optional[Any] = Field(alias="masterUri")
    image_uri: Optional[Any] = Field(alias="imageUri")
    text_uri: Optional[Any] = Field(alias="textUri")
    audio_uri: Optional[Any] = Field(alias="audioUri")
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    summary: Optional[str]
    custom_summary: Optional[str] = Field(alias="customSummary")
    keywords: Optional[List[str]]
    bullets: Optional[List[str]]
    headlines: Optional[List[str]]
    posts: Optional[List[str]]
    chapters: Optional[List[str]]
    questions: Optional[List[str]]
    video: Optional["QueryContentsContentsResultsVideo"]
    audio: Optional["QueryContentsContentsResultsAudio"]
    image: Optional["QueryContentsContentsResultsImage"]
    document: Optional["QueryContentsContentsResultsDocument"]
    email: Optional["QueryContentsContentsResultsEmail"]
    issue: Optional["QueryContentsContentsResultsIssue"]
    package: Optional["QueryContentsContentsResultsPackage"]
    language: Optional["QueryContentsContentsResultsLanguage"]
    parent: Optional["QueryContentsContentsResultsParent"]
    children: Optional[List[Optional["QueryContentsContentsResultsChildren"]]]
    feed: Optional["QueryContentsContentsResultsFeed"]
    collections: Optional[List[Optional["QueryContentsContentsResultsCollections"]]]
    links: Optional[List["QueryContentsContentsResultsLinks"]]
    observations: Optional[List[Optional["QueryContentsContentsResultsObservations"]]]
    workflow: Optional["QueryContentsContentsResultsWorkflow"]
    pages: Optional[List["QueryContentsContentsResultsPages"]]
    segments: Optional[List["QueryContentsContentsResultsSegments"]]
    error: Optional[str]


class QueryContentsContentsResultsOwner(BaseModel):
    id: str


class QueryContentsContentsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class QueryContentsContentsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryContentsContentsResultsVideo(BaseModel):
    width: Optional[int]
    height: Optional[int]
    duration: Optional[Any]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    title: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]


class QueryContentsContentsResultsAudio(BaseModel):
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]
    series: Optional[str]
    episode: Optional[str]
    episode_type: Optional[str] = Field(alias="episodeType")
    season: Optional[str]
    publisher: Optional[str]
    copyright: Optional[str]
    genre: Optional[str]
    title: Optional[str]
    description: Optional[str]
    bitrate: Optional[int]
    channels: Optional[int]
    sample_rate: Optional[int] = Field(alias="sampleRate")
    bits_per_sample: Optional[int] = Field(alias="bitsPerSample")
    duration: Optional[Any]


class QueryContentsContentsResultsImage(BaseModel):
    width: Optional[int]
    height: Optional[int]
    resolution_x: Optional[int] = Field(alias="resolutionX")
    resolution_y: Optional[int] = Field(alias="resolutionY")
    bits_per_component: Optional[int] = Field(alias="bitsPerComponent")
    components: Optional[int]
    projection_type: Optional[ImageProjectionTypes] = Field(alias="projectionType")
    orientation: Optional[OrientationTypes]
    description: Optional[str]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    lens: Optional[str]
    focal_length: Optional[float] = Field(alias="focalLength")
    exposure_time: Optional[str] = Field(alias="exposureTime")
    f_number: Optional[str] = Field(alias="fNumber")
    iso: Optional[str]
    heading: Optional[float]
    pitch: Optional[float]


class QueryContentsContentsResultsDocument(BaseModel):
    title: Optional[str]
    subject: Optional[str]
    summary: Optional[str]
    author: Optional[str]
    publisher: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    page_count: Optional[int] = Field(alias="pageCount")
    worksheet_count: Optional[int] = Field(alias="worksheetCount")
    slide_count: Optional[int] = Field(alias="slideCount")
    word_count: Optional[int] = Field(alias="wordCount")
    line_count: Optional[int] = Field(alias="lineCount")
    paragraph_count: Optional[int] = Field(alias="paragraphCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")
    has_digital_signature: Optional[bool] = Field(alias="hasDigitalSignature")


class QueryContentsContentsResultsEmail(BaseModel):
    identifier: Optional[str]
    subject: Optional[str]
    labels: Optional[List[Optional[str]]]
    sensitivity: Optional[MailSensitivity]
    priority: Optional[MailPriority]
    importance: Optional[MailImportance]
    from_: Optional[List[Optional["QueryContentsContentsResultsEmailFrom"]]] = Field(
        alias="from"
    )
    to: Optional[List[Optional["QueryContentsContentsResultsEmailTo"]]]
    cc: Optional[List[Optional["QueryContentsContentsResultsEmailCc"]]]
    bcc: Optional[List[Optional["QueryContentsContentsResultsEmailBcc"]]]


class QueryContentsContentsResultsEmailFrom(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsEmailTo(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsEmailCc(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsEmailBcc(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsIssue(BaseModel):
    identifier: Optional[str]
    title: Optional[str]
    project: Optional[str]
    team: Optional[str]
    status: Optional[str]
    priority: Optional[str]
    type: Optional[str]
    labels: Optional[List[Optional[str]]]


class QueryContentsContentsResultsPackage(BaseModel):
    file_count: Optional[int] = Field(alias="fileCount")
    folder_count: Optional[int] = Field(alias="folderCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")


class QueryContentsContentsResultsLanguage(BaseModel):
    languages: Optional[List[Optional[str]]]


class QueryContentsContentsResultsParent(BaseModel):
    id: str
    name: str


class QueryContentsContentsResultsChildren(BaseModel):
    id: str
    name: str


class QueryContentsContentsResultsFeed(BaseModel):
    id: str
    name: str


class QueryContentsContentsResultsCollections(BaseModel):
    id: str
    name: str


class QueryContentsContentsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")


class QueryContentsContentsResultsObservations(BaseModel):
    id: str
    type: ObservableTypes
    observable: "QueryContentsContentsResultsObservationsObservable"
    related: Optional["QueryContentsContentsResultsObservationsRelated"]
    related_type: Optional[ObservableTypes] = Field(alias="relatedType")
    relation: Optional[str]
    occurrences: Optional[
        List[Optional["QueryContentsContentsResultsObservationsOccurrences"]]
    ]
    state: EntityState


class QueryContentsContentsResultsObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class QueryContentsContentsResultsObservationsRelated(BaseModel):
    id: str
    name: Optional[str]


class QueryContentsContentsResultsObservationsOccurrences(BaseModel):
    type: Optional[OccurrenceTypes]
    confidence: Optional[float]
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_index: Optional[int] = Field(alias="pageIndex")
    bounding_box: Optional[
        "QueryContentsContentsResultsObservationsOccurrencesBoundingBox"
    ] = Field(alias="boundingBox")


class QueryContentsContentsResultsObservationsOccurrencesBoundingBox(BaseModel):
    left: Optional[float]
    top: Optional[float]
    width: Optional[float]
    height: Optional[float]


class QueryContentsContentsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryContentsContentsResultsPages(BaseModel):
    index: Optional[int]
    relevance: Optional[float]
    chunks: Optional[List[Optional["QueryContentsContentsResultsPagesChunks"]]]


class QueryContentsContentsResultsPagesChunks(BaseModel):
    index: Optional[int]
    page_index: Optional[int] = Field(alias="pageIndex")
    row_index: Optional[int] = Field(alias="rowIndex")
    column_index: Optional[int] = Field(alias="columnIndex")
    confidence: Optional[float]
    text: Optional[str]
    role: Optional[TextRoles]
    relevance: Optional[float]


class QueryContentsContentsResultsSegments(BaseModel):
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    text: Optional[str]
    relevance: Optional[float]


QueryContents.model_rebuild()
QueryContentsContents.model_rebuild()
QueryContentsContentsResults.model_rebuild()
QueryContentsContentsResultsEmail.model_rebuild()
QueryContentsContentsResultsObservations.model_rebuild()
QueryContentsContentsResultsObservationsOccurrences.model_rebuild()
QueryContentsContentsResultsPages.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalDevice(BaseModel):
    update_medical_device: Optional["UpdateMedicalDeviceUpdateMedicalDevice"] = Field(
        alias="updateMedicalDevice"
    )


class UpdateMedicalDeviceUpdateMedicalDevice(BaseModel):
    id: str
    name: str


UpdateMedicalDevice.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class AddContentsToCollections(BaseModel):
    add_contents_to_collections: Optional[
        List[Optional["AddContentsToCollectionsAddContentsToCollections"]]
    ] = Field(alias="addContentsToCollections")


class AddContentsToCollectionsAddContentsToCollections(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        List[Optional["AddContentsToCollectionsAddContentsToCollectionsContents"]]
    ]


class AddContentsToCollectionsAddContentsToCollectionsContents(BaseModel):
    id: str
    name: str


AddContentsToCollections.model_rebuild()
AddContentsToCollectionsAddContentsToCollections.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    EmailListingTypes,
    EntityState,
    FeedListingTypes,
    FeedServiceTypes,
    FeedTypes,
    NotionTypes,
    SearchServiceTypes,
    SharePointAuthenticationTypes,
    SiteTypes,
    TimedPolicyRecurrenceTypes,
    YouTubeTypes,
)


class QueryFeeds(BaseModel):
    feeds: Optional["QueryFeedsFeeds"]


class QueryFeedsFeeds(BaseModel):
    results: Optional[List[Optional["QueryFeedsFeedsResults"]]]


class QueryFeedsFeedsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "QueryFeedsFeedsResultsOwner"
    state: EntityState
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: FeedTypes
    site: Optional["QueryFeedsFeedsResultsSite"]
    email: Optional["QueryFeedsFeedsResultsEmail"]
    issue: Optional["QueryFeedsFeedsResultsIssue"]
    rss: Optional["QueryFeedsFeedsResultsRss"]
    web: Optional["QueryFeedsFeedsResultsWeb"]
    search: Optional["QueryFeedsFeedsResultsSearch"]
    reddit: Optional["QueryFeedsFeedsResultsReddit"]
    notion: Optional["QueryFeedsFeedsResultsNotion"]
    youtube: Optional["QueryFeedsFeedsResultsYoutube"]
    slack: Optional["QueryFeedsFeedsResultsSlack"]
    discord: Optional["QueryFeedsFeedsResultsDiscord"]
    error: Optional[str]
    last_post_date: Optional[Any] = Field(alias="lastPostDate")
    last_read_date: Optional[Any] = Field(alias="lastReadDate")
    read_count: Optional[int] = Field(alias="readCount")
    workflow: Optional["QueryFeedsFeedsResultsWorkflow"]
    schedule_policy: Optional["QueryFeedsFeedsResultsSchedulePolicy"] = Field(
        alias="schedulePolicy"
    )


class QueryFeedsFeedsResultsOwner(BaseModel):
    id: str


class QueryFeedsFeedsResultsSite(BaseModel):
    site_type: SiteTypes = Field(alias="siteType")
    type: FeedServiceTypes
    is_recursive: Optional[bool] = Field(alias="isRecursive")
    s_3: Optional["QueryFeedsFeedsResultsSiteS3"] = Field(alias="s3")
    azure_blob: Optional["QueryFeedsFeedsResultsSiteAzureBlob"] = Field(
        alias="azureBlob"
    )
    azure_file: Optional["QueryFeedsFeedsResultsSiteAzureFile"] = Field(
        alias="azureFile"
    )
    google: Optional["QueryFeedsFeedsResultsSiteGoogle"]
    share_point: Optional["QueryFeedsFeedsResultsSiteSharePoint"] = Field(
        alias="sharePoint"
    )
    one_drive: Optional["QueryFeedsFeedsResultsSiteOneDrive"] = Field(alias="oneDrive")
    google_drive: Optional["QueryFeedsFeedsResultsSiteGoogleDrive"] = Field(
        alias="googleDrive"
    )
    github: Optional["QueryFeedsFeedsResultsSiteGithub"]
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsSiteS3(BaseModel):
    access_key: Optional[str] = Field(alias="accessKey")
    secret_access_key: Optional[str] = Field(alias="secretAccessKey")
    bucket_name: Optional[str] = Field(alias="bucketName")
    prefix: Optional[str]
    region: Optional[str]


class QueryFeedsFeedsResultsSiteAzureBlob(BaseModel):
    storage_access_key: Optional[str] = Field(alias="storageAccessKey")
    account_name: Optional[str] = Field(alias="accountName")
    container_name: Optional[str] = Field(alias="containerName")
    prefix: Optional[str]


class QueryFeedsFeedsResultsSiteAzureFile(BaseModel):
    storage_access_key: Optional[str] = Field(alias="storageAccessKey")
    account_name: Optional[str] = Field(alias="accountName")
    share_name: Optional[str] = Field(alias="shareName")
    prefix: Optional[str]


class QueryFeedsFeedsResultsSiteGoogle(BaseModel):
    credentials: Optional[str]
    container_name: Optional[str] = Field(alias="containerName")
    prefix: Optional[str]


class QueryFeedsFeedsResultsSiteSharePoint(BaseModel):
    authentication_type: SharePointAuthenticationTypes = Field(
        alias="authenticationType"
    )
    account_name: str = Field(alias="accountName")
    library_id: str = Field(alias="libraryId")
    folder_id: Optional[str] = Field(alias="folderId")
    tenant_id: Optional[str] = Field(alias="tenantId")
    refresh_token: Optional[str] = Field(alias="refreshToken")


class QueryFeedsFeedsResultsSiteOneDrive(BaseModel):
    folder_id: Optional[str] = Field(alias="folderId")
    refresh_token: str = Field(alias="refreshToken")


class QueryFeedsFeedsResultsSiteGoogleDrive(BaseModel):
    folder_id: Optional[str] = Field(alias="folderId")
    refresh_token: str = Field(alias="refreshToken")
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class QueryFeedsFeedsResultsSiteGithub(BaseModel):
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")


class QueryFeedsFeedsResultsEmail(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    google: Optional["QueryFeedsFeedsResultsEmailGoogle"]
    microsoft: Optional["QueryFeedsFeedsResultsEmailMicrosoft"]
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsEmailGoogle(BaseModel):
    type: Optional[EmailListingTypes]
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class QueryFeedsFeedsResultsEmailMicrosoft(BaseModel):
    type: Optional[EmailListingTypes]
    refresh_token: str = Field(alias="refreshToken")


class QueryFeedsFeedsResultsIssue(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    jira: Optional["QueryFeedsFeedsResultsIssueJira"]
    linear: Optional["QueryFeedsFeedsResultsIssueLinear"]
    github: Optional["QueryFeedsFeedsResultsIssueGithub"]
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsIssueJira(BaseModel):
    uri: Any
    project: str
    email: str
    token: str
    offset: Optional[Any]


class QueryFeedsFeedsResultsIssueLinear(BaseModel):
    key: str
    project: str


class QueryFeedsFeedsResultsIssueGithub(BaseModel):
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")


class QueryFeedsFeedsResultsRss(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    uri: Any


class QueryFeedsFeedsResultsWeb(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    uri: Any
    include_files: Optional[bool] = Field(alias="includeFiles")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")


class QueryFeedsFeedsResultsSearch(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[SearchServiceTypes]
    text: str


class QueryFeedsFeedsResultsReddit(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    subreddit_name: str = Field(alias="subredditName")


class QueryFeedsFeedsResultsNotion(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    token: str
    identifiers: List[str]
    type: NotionTypes


class QueryFeedsFeedsResultsYoutube(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: YouTubeTypes
    video_name: Optional[str] = Field(alias="videoName")
    video_identifiers: Optional[List[str]] = Field(alias="videoIdentifiers")
    channel_identifier: Optional[str] = Field(alias="channelIdentifier")
    playlist_identifier: Optional[str] = Field(alias="playlistIdentifier")


class QueryFeedsFeedsResultsSlack(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    token: str
    channel: str
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class QueryFeedsFeedsResultsDiscord(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    token: str
    channel: str
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class QueryFeedsFeedsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryFeedsFeedsResultsSchedulePolicy(BaseModel):
    recurrence_type: Optional[TimedPolicyRecurrenceTypes] = Field(
        alias="recurrenceType"
    )
    repeat_interval: Optional[Any] = Field(alias="repeatInterval")


QueryFeeds.model_rebuild()
QueryFeedsFeeds.model_rebuild()
QueryFeedsFeedsResults.model_rebuild()
QueryFeedsFeedsResultsSite.model_rebuild()
QueryFeedsFeedsResultsEmail.model_rebuild()
QueryFeedsFeedsResultsIssue.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalStudy(BaseModel):
    delete_medical_study: Optional["DeleteMedicalStudyDeleteMedicalStudy"] = Field(
        alias="deleteMedicalStudy"
    )


class DeleteMedicalStudyDeleteMedicalStudy(BaseModel):
    id: str
    state: EntityState


DeleteMedicalStudy.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountSpecifications(BaseModel):
    count_specifications: Optional["CountSpecificationsCountSpecifications"] = Field(
        alias="countSpecifications"
    )


class CountSpecificationsCountSpecifications(BaseModel):
    count: Optional[Any]


CountSpecifications.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalTherapy(BaseModel):
    delete_medical_therapy: Optional["DeleteMedicalTherapyDeleteMedicalTherapy"] = (
        Field(alias="deleteMedicalTherapy")
    )


class DeleteMedicalTherapyDeleteMedicalTherapy(BaseModel):
    id: str
    state: EntityState


DeleteMedicalTherapy.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalTherapy(BaseModel):
    create_medical_therapy: Optional["CreateMedicalTherapyCreateMedicalTherapy"] = (
        Field(alias="createMedicalTherapy")
    )


class CreateMedicalTherapyCreateMedicalTherapy(BaseModel):
    id: str
    name: str


CreateMedicalTherapy.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalCondition(BaseModel):
    delete_medical_condition: Optional[
        "DeleteMedicalConditionDeleteMedicalCondition"
    ] = Field(alias="deleteMedicalCondition")


class DeleteMedicalConditionDeleteMedicalCondition(BaseModel):
    id: str
    state: EntityState


DeleteMedicalCondition.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, FeedTypes


class CreateFeed(BaseModel):
    create_feed: Optional["CreateFeedCreateFeed"] = Field(alias="createFeed")


class CreateFeedCreateFeed(BaseModel):
    id: str
    name: str
    state: EntityState
    type: FeedTypes


CreateFeed.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    ConversationRoleTypes,
    ConversationTypes,
    EntityState,
    FileTypes,
    ImageProjectionTypes,
    ModelServiceTypes,
    ObservableTypes,
    OrientationTypes,
)


class QueryConversations(BaseModel):
    conversations: Optional["QueryConversationsConversations"]


class QueryConversationsConversations(BaseModel):
    results: Optional[List[Optional["QueryConversationsConversationsResults"]]]


class QueryConversationsConversationsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "QueryConversationsConversationsResultsOwner"
    state: EntityState
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: Optional[ConversationTypes]
    messages: Optional[List[Optional["QueryConversationsConversationsResultsMessages"]]]
    specification: Optional["QueryConversationsConversationsResultsSpecification"]
    filter: Optional["QueryConversationsConversationsResultsFilter"]
    augmented_filter: Optional[
        "QueryConversationsConversationsResultsAugmentedFilter"
    ] = Field(alias="augmentedFilter")


class QueryConversationsConversationsResultsOwner(BaseModel):
    id: str


class QueryConversationsConversationsResultsMessages(BaseModel):
    role: ConversationRoleTypes
    author: Optional[str]
    message: Optional[str]
    citations: Optional[
        List[Optional["QueryConversationsConversationsResultsMessagesCitations"]]
    ]
    tool_calls: Optional[
        List[Optional["QueryConversationsConversationsResultsMessagesToolCalls"]]
    ] = Field(alias="toolCalls")
    tokens: Optional[int]
    throughput: Optional[float]
    completion_time: Optional[Any] = Field(alias="completionTime")
    timestamp: Optional[Any]
    model_service: Optional[ModelServiceTypes] = Field(alias="modelService")
    model: Optional[str]


class QueryConversationsConversationsResultsMessagesCitations(BaseModel):
    content: Optional["QueryConversationsConversationsResultsMessagesCitationsContent"]
    index: Optional[int]
    text: str
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_number: Optional[int] = Field(alias="pageNumber")
    frame_number: Optional[int] = Field(alias="frameNumber")


class QueryConversationsConversationsResultsMessagesCitationsContent(BaseModel):
    id: str
    name: str
    state: EntityState
    original_date: Optional[Any] = Field(alias="originalDate")
    identifier: Optional[str]
    uri: Optional[Any]
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    format: Optional[str]
    format_name: Optional[str] = Field(alias="formatName")
    file_extension: Optional[str] = Field(alias="fileExtension")
    file_name: Optional[str] = Field(alias="fileName")
    file_size: Optional[Any] = Field(alias="fileSize")
    master_uri: Optional[Any] = Field(alias="masterUri")
    image_uri: Optional[Any] = Field(alias="imageUri")
    text_uri: Optional[Any] = Field(alias="textUri")
    audio_uri: Optional[Any] = Field(alias="audioUri")
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    summary: Optional[str]
    custom_summary: Optional[str] = Field(alias="customSummary")
    keywords: Optional[List[str]]
    bullets: Optional[List[str]]
    headlines: Optional[List[str]]
    posts: Optional[List[str]]
    chapters: Optional[List[str]]
    questions: Optional[List[str]]
    video: Optional[
        "QueryConversationsConversationsResultsMessagesCitationsContentVideo"
    ]
    audio: Optional[
        "QueryConversationsConversationsResultsMessagesCitationsContentAudio"
    ]
    image: Optional[
        "QueryConversationsConversationsResultsMessagesCitationsContentImage"
    ]
    document: Optional[
        "QueryConversationsConversationsResultsMessagesCitationsContentDocument"
    ]


class QueryConversationsConversationsResultsMessagesCitationsContentVideo(BaseModel):
    width: Optional[int]
    height: Optional[int]
    duration: Optional[Any]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    title: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]


class QueryConversationsConversationsResultsMessagesCitationsContentAudio(BaseModel):
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]
    series: Optional[str]
    episode: Optional[str]
    episode_type: Optional[str] = Field(alias="episodeType")
    season: Optional[str]
    publisher: Optional[str]
    copyright: Optional[str]
    genre: Optional[str]
    title: Optional[str]
    description: Optional[str]
    bitrate: Optional[int]
    channels: Optional[int]
    sample_rate: Optional[int] = Field(alias="sampleRate")
    bits_per_sample: Optional[int] = Field(alias="bitsPerSample")
    duration: Optional[Any]


class QueryConversationsConversationsResultsMessagesCitationsContentImage(BaseModel):
    width: Optional[int]
    height: Optional[int]
    resolution_x: Optional[int] = Field(alias="resolutionX")
    resolution_y: Optional[int] = Field(alias="resolutionY")
    bits_per_component: Optional[int] = Field(alias="bitsPerComponent")
    components: Optional[int]
    projection_type: Optional[ImageProjectionTypes] = Field(alias="projectionType")
    orientation: Optional[OrientationTypes]
    description: Optional[str]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    lens: Optional[str]
    focal_length: Optional[float] = Field(alias="focalLength")
    exposure_time: Optional[str] = Field(alias="exposureTime")
    f_number: Optional[str] = Field(alias="fNumber")
    iso: Optional[str]
    heading: Optional[float]
    pitch: Optional[float]


class QueryConversationsConversationsResultsMessagesCitationsContentDocument(BaseModel):
    title: Optional[str]
    subject: Optional[str]
    summary: Optional[str]
    author: Optional[str]
    publisher: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    page_count: Optional[int] = Field(alias="pageCount")
    worksheet_count: Optional[int] = Field(alias="worksheetCount")
    slide_count: Optional[int] = Field(alias="slideCount")
    word_count: Optional[int] = Field(alias="wordCount")
    line_count: Optional[int] = Field(alias="lineCount")
    paragraph_count: Optional[int] = Field(alias="paragraphCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")
    has_digital_signature: Optional[bool] = Field(alias="hasDigitalSignature")


class QueryConversationsConversationsResultsMessagesToolCalls(BaseModel):
    id: Optional[str]
    name: str
    arguments: str


class QueryConversationsConversationsResultsSpecification(BaseModel):
    id: str
    name: str


class QueryConversationsConversationsResultsFilter(BaseModel):
    date_range: Optional["QueryConversationsConversationsResultsFilterDateRange"] = (
        Field(alias="dateRange")
    )
    creation_date_range: Optional[
        "QueryConversationsConversationsResultsFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    contents: Optional[List["QueryConversationsConversationsResultsFilterContents"]]
    feeds: Optional[List["QueryConversationsConversationsResultsFilterFeeds"]]
    workflows: Optional[List["QueryConversationsConversationsResultsFilterWorkflows"]]
    collections: Optional[
        List["QueryConversationsConversationsResultsFilterCollections"]
    ]
    observations: Optional[
        List["QueryConversationsConversationsResultsFilterObservations"]
    ]
    or_: Optional[List["QueryConversationsConversationsResultsFilterOr"]] = Field(
        alias="or"
    )
    and_: Optional[List["QueryConversationsConversationsResultsFilterAnd"]] = Field(
        alias="and"
    )


class QueryConversationsConversationsResultsFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsFilterContents(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryConversationsConversationsResultsFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryConversationsConversationsResultsFilterObservationsObservable(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterOr(BaseModel):
    feeds: Optional[List["QueryConversationsConversationsResultsFilterOrFeeds"]]
    workflows: Optional[List["QueryConversationsConversationsResultsFilterOrWorkflows"]]
    collections: Optional[
        List["QueryConversationsConversationsResultsFilterOrCollections"]
    ]
    observations: Optional[
        List["QueryConversationsConversationsResultsFilterOrObservations"]
    ]


class QueryConversationsConversationsResultsFilterOrFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterOrWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterOrCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryConversationsConversationsResultsFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryConversationsConversationsResultsFilterOrObservationsObservable(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterAnd(BaseModel):
    feeds: Optional[List["QueryConversationsConversationsResultsFilterAndFeeds"]]
    workflows: Optional[
        List["QueryConversationsConversationsResultsFilterAndWorkflows"]
    ]
    collections: Optional[
        List["QueryConversationsConversationsResultsFilterAndCollections"]
    ]
    observations: Optional[
        List["QueryConversationsConversationsResultsFilterAndObservations"]
    ]


class QueryConversationsConversationsResultsFilterAndFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterAndWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterAndCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryConversationsConversationsResultsFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryConversationsConversationsResultsFilterAndObservationsObservable(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilter(BaseModel):
    date_range: Optional[
        "QueryConversationsConversationsResultsAugmentedFilterDateRange"
    ] = Field(alias="dateRange")
    creation_date_range: Optional[
        "QueryConversationsConversationsResultsAugmentedFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    contents: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterContents"]
    ]
    feeds: Optional[List["QueryConversationsConversationsResultsAugmentedFilterFeeds"]]
    workflows: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterWorkflows"]
    ]
    collections: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterCollections"]
    ]
    observations: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterObservations"]
    ]
    or_: Optional[List["QueryConversationsConversationsResultsAugmentedFilterOr"]] = (
        Field(alias="or")
    )
    and_: Optional[List["QueryConversationsConversationsResultsAugmentedFilterAnd"]] = (
        Field(alias="and")
    )


class QueryConversationsConversationsResultsAugmentedFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsAugmentedFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsAugmentedFilterContents(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterObservations(BaseModel):
    type: ObservableTypes
    observable: (
        "QueryConversationsConversationsResultsAugmentedFilterObservationsObservable"
    )
    states: Optional[List[Optional[EntityState]]]


class QueryConversationsConversationsResultsAugmentedFilterObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterOr(BaseModel):
    feeds: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterOrFeeds"]
    ]
    workflows: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterOrWorkflows"]
    ]
    collections: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterOrCollections"]
    ]
    observations: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterOrObservations"]
    ]


class QueryConversationsConversationsResultsAugmentedFilterOrFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterOrWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterOrCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: (
        "QueryConversationsConversationsResultsAugmentedFilterOrObservationsObservable"
    )
    states: Optional[List[Optional[EntityState]]]


class QueryConversationsConversationsResultsAugmentedFilterOrObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterAnd(BaseModel):
    feeds: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterAndFeeds"]
    ]
    workflows: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterAndWorkflows"]
    ]
    collections: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterAndCollections"]
    ]
    observations: Optional[
        List["QueryConversationsConversationsResultsAugmentedFilterAndObservations"]
    ]


class QueryConversationsConversationsResultsAugmentedFilterAndFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterAndWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterAndCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: (
        "QueryConversationsConversationsResultsAugmentedFilterAndObservationsObservable"
    )
    states: Optional[List[Optional[EntityState]]]


class QueryConversationsConversationsResultsAugmentedFilterAndObservationsObservable(
    BaseModel
):
    id: str


QueryConversations.model_rebuild()
QueryConversationsConversations.model_rebuild()
QueryConversationsConversationsResults.model_rebuild()
QueryConversationsConversationsResultsMessages.model_rebuild()
QueryConversationsConversationsResultsMessagesCitations.model_rebuild()
QueryConversationsConversationsResultsMessagesCitationsContent.model_rebuild()
QueryConversationsConversationsResultsFilter.model_rebuild()
QueryConversationsConversationsResultsFilterObservations.model_rebuild()
QueryConversationsConversationsResultsFilterOr.model_rebuild()
QueryConversationsConversationsResultsFilterOrObservations.model_rebuild()
QueryConversationsConversationsResultsFilterAnd.model_rebuild()
QueryConversationsConversationsResultsFilterAndObservations.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilter.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterObservations.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterOr.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterOrObservations.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterAnd.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterAndObservations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateLabel(BaseModel):
    create_label: Optional["CreateLabelCreateLabel"] = Field(alias="createLabel")


class CreateLabelCreateLabel(BaseModel):
    id: str
    name: str


CreateLabel.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalTest(BaseModel):
    update_medical_test: Optional["UpdateMedicalTestUpdateMedicalTest"] = Field(
        alias="updateMedicalTest"
    )


class UpdateMedicalTestUpdateMedicalTest(BaseModel):
    id: str
    name: str


UpdateMedicalTest.model_rebuild()
